@@ -14,7 +14,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import base64
 import calendar
 import ctypes
@@ -30,9 +29,6 @@ if sys.version >= "3":
     long = int
     basestring = unicode = str
 
-from py4j.protocol import register_input_converter
-from py4j.java_gateway import JavaClass
-from pyjava.serializers import CloudPickleSerializer
 
 __all__ = [
     "DataType", "NullType", "StringType", "BinaryType", "BooleanType", "DateType",
@@ -711,6 +707,7 @@ class UserDefinedType(DataType):
         return json.dumps(self.jsonValue(), separators=(',', ':'), sort_keys=True)
 
     def jsonValue(self):
+        from pyjava.serializers import CloudPickleSerializer
         if self.scalaUDT():
             assert self.module() != '__main__', 'UDT in __main__ cannot work with ScalaUDT'
             schema = {
@@ -732,6 +729,7 @@ class UserDefinedType(DataType):
 
     @classmethod
     def fromJson(cls, json):
+        from pyjava.serializers import CloudPickleSerializer
         pyUDT = str(json["pyClass"])  # convert unicode to str
         split = pyUDT.rfind(".")
         pyModule = pyUDT[:split]
@@ -1582,33 +1580,6 @@ class Row(tuple):
             return "<Row(%s)>" % ", ".join("%r" % field for field in self)
 
 
-class DateConverter(object):
-    def can_convert(self, obj):
-        return isinstance(obj, datetime.date)
-
-    def convert(self, obj, gateway_client):
-        Date = JavaClass("java.sql.Date", gateway_client)
-        return Date.valueOf(obj.strftime("%Y-%m-%d"))
-
-
-class DatetimeConverter(object):
-    def can_convert(self, obj):
-        return isinstance(obj, datetime.datetime)
-
-    def convert(self, obj, gateway_client):
-        Timestamp = JavaClass("java.sql.Timestamp", gateway_client)
-        seconds = (calendar.timegm(obj.utctimetuple()) if obj.tzinfo
-                   else time.mktime(obj.timetuple()))
-        t = Timestamp(int(seconds) * 1000)
-        t.setNanos(obj.microsecond * 1000)
-        return t
-
-
-# datetime is a subclass of date, we should register DatetimeConverter first
-register_input_converter(DatetimeConverter())
-register_input_converter(DateConverter())
-
-
 def to_arrow_type(dt):
     """ Convert Spark data type to pyarrow type
     """
